@@ -1,11 +1,15 @@
 from .version import __version__
+print (f'(Running XClone {__version__})')
 
 # set simplified alias
 from . import preprocessing as pp
 from . import plot as pl
 from . import analysis as al
 from . import model
+from . import data
 
 from .model import phasing as phasing
 from .model import mixture as mixture
-from .model import XClone_VB_model as XClone_VB_model
+
+from ._logging import get_logger
+from ._config import XCloneConfig, settings
\ No newline at end of file
