@@ -1,4 +1,5 @@
-"""XClone analysis."""
+"""XClone analysis.
+"""
 
 from .extract import dir_make
 from .extract import extract_xclone_matrix
