@@ -1,4 +1,5 @@
-
+"""Base functions for XClone clustering analysis.
+"""
 
 def XClustering(Xdata, Xlayer, PCA_comp = 30, n_clusters = 5, method = "k-means"):
     """
