@@ -1,6 +1,6 @@
-
-
-
+"""Utility functions for XClone.
+"""
+# Author: Rongting Huang
 
 def pairwise0(iterable_arr):
     """
@@ -43,7 +43,3 @@ def pairwise2(iterable_arr):
     for i,k in zip(iterable_arr[0::1], iterable_arr[1::1]):
         print(str(i), '+', str(k), '=', str(i+k))
     return 0
-
-
-## reorder  todo
-# reorder numpy array/Xdata according to the cell order
