@@ -397,7 +397,7 @@ def CNV_combine_visualization(Xdata,
         Xheatmap(res_cnv_ad_re, cell_anno_key = cell_anno_key, 
             center = 2,
             colorbar_ticks = [0, 1, 2, 3, 4], 
-            colorbar_label = ["copy neutral", "copy loss", "copy loss", "LOH", "copy gain"],
+            colorbar_label = ["copy neutral", "copy lossA", "copy lossB", "LOH", "copy gain"],
             cmap = color_map, **kwargs)
 
     if mode == 2:
