@@ -1,4 +1,6 @@
-"""XClone plotting."""
+"""XClone plotting.
+"""
+
 ## base
 from ._test import random_assign_celltype
 
